All of lore.kernel.org
 help / color / mirror / Atom feed
From: Arnaud Pouliquen <arnaud.pouliquen@foss.st.com>
To: Bjorn Andersson <bjorn.andersson@linaro.org>,
	Ohad Ben-Cohen <ohad@wizery.com>,
	Mathieu Poirier <mathieu.poirier@linaro.org>,
	Andy Gross <agross@kernel.org>
Cc: <linux-remoteproc@vger.kernel.org>,
	<linux-kernel@vger.kernel.org>,
	<linux-stm32@st-md-mailman.stormreply.com>,
	<linux-arm-msm@vger.kernel.org>, <arnaud.pouliquen@foss.st.com>
Subject: [PATCH v5 07/16] rpmsg: update rpmsg_chrdev_register_device function
Date: Fri, 19 Feb 2021 12:14:52 +0100	[thread overview]
Message-ID: <20210219111501.14261-8-arnaud.pouliquen@foss.st.com> (raw)
In-Reply-To: <20210219111501.14261-1-arnaud.pouliquen@foss.st.com>

As driver is now the rpmsg_ioctl, rename the function.
In addition, initialize the rpdev addresses to RPMSG_ADDR_ANY as not
defined.

Signed-off-by: Arnaud Pouliquen <arnaud.pouliquen@foss.st.com>
---
 drivers/rpmsg/qcom_glink_native.c |  2 +-
 drivers/rpmsg/qcom_smd.c          |  2 +-
 drivers/rpmsg/rpmsg_ctrl.c        |  2 +-
 drivers/rpmsg/rpmsg_internal.h    | 10 ++++++----
 4 files changed, 9 insertions(+), 7 deletions(-)

diff --git a/drivers/rpmsg/qcom_glink_native.c b/drivers/rpmsg/qcom_glink_native.c
index 27a05167c18c..d4e4dd482614 100644
--- a/drivers/rpmsg/qcom_glink_native.c
+++ b/drivers/rpmsg/qcom_glink_native.c
@@ -1625,7 +1625,7 @@ static int qcom_glink_create_chrdev(struct qcom_glink *glink)
 	rpdev->dev.parent = glink->dev;
 	rpdev->dev.release = qcom_glink_device_release;
 
-	return rpmsg_chrdev_register_device(rpdev);
+	return rpmsg_ctrl_register_device(rpdev);
 }
 
 struct qcom_glink *qcom_glink_native_probe(struct device *dev,
diff --git a/drivers/rpmsg/qcom_smd.c b/drivers/rpmsg/qcom_smd.c
index 19903de6268d..40a1c415c775 100644
--- a/drivers/rpmsg/qcom_smd.c
+++ b/drivers/rpmsg/qcom_smd.c
@@ -1097,7 +1097,7 @@ static int qcom_smd_create_chrdev(struct qcom_smd_edge *edge)
 	qsdev->rpdev.dev.parent = &edge->dev;
 	qsdev->rpdev.dev.release = qcom_smd_release_device;
 
-	return rpmsg_chrdev_register_device(&qsdev->rpdev);
+	return rpmsg_ctrl_register_device(&qsdev->rpdev);
 }
 
 /*
diff --git a/drivers/rpmsg/rpmsg_ctrl.c b/drivers/rpmsg/rpmsg_ctrl.c
index fa05b67d24da..2e43b4096aa8 100644
--- a/drivers/rpmsg/rpmsg_ctrl.c
+++ b/drivers/rpmsg/rpmsg_ctrl.c
@@ -180,7 +180,7 @@ static struct rpmsg_driver rpmsg_ctrl_driver = {
 	.probe = rpmsg_ctrl_probe,
 	.remove = rpmsg_ctrl_remove,
 	.drv = {
-		.name = "rpmsg_chrdev",
+		.name = KBUILD_MODNAME,
 	},
 };
 
diff --git a/drivers/rpmsg/rpmsg_internal.h b/drivers/rpmsg/rpmsg_internal.h
index a76c344253bf..7428f4465d17 100644
--- a/drivers/rpmsg/rpmsg_internal.h
+++ b/drivers/rpmsg/rpmsg_internal.h
@@ -82,16 +82,18 @@ struct rpmsg_device *rpmsg_create_channel(struct rpmsg_device *rpdev,
 int rpmsg_release_channel(struct rpmsg_device *rpdev,
 			  struct rpmsg_channel_info *chinfo);
 /**
  * rpmsg_chrdev_register_device() - register chrdev device based on rpdev
  * @rpdev:	prepared rpdev to be used for creating endpoints
  *
  * This function wraps rpmsg_register_device() preparing the rpdev for use as
  * basis for the rpmsg chrdev.
  */
-static inline int rpmsg_chrdev_register_device(struct rpmsg_device *rpdev)
+static inline int rpmsg_ctrl_register_device(struct rpmsg_device *rpdev)
 {
-	strcpy(rpdev->id.name, "rpmsg_chrdev");
-	rpdev->driver_override = "rpmsg_chrdev";
+	strcpy(rpdev->id.name, "rpmsg_ctrl");
+	rpdev->driver_override = "rpmsg_ctrl";
+	rpdev->src = RPMSG_ADDR_ANY;
+	rpdev->dst = RPMSG_ADDR_ANY;
 
 	return rpmsg_register_device(rpdev);
 }
@@ -82,16 +82,18 @@ struct rpmsg_device *rpmsg_create_channel(struct rpmsg_device *rpdev,
 			  struct rpmsg_channel_info *chinfo);
 /**
- * rpmsg_chrdev_register_device() - register chrdev device based on rpdev
+ * rpmsg_ctrl_register_device() - register a char device for control based on rpdev
  * @rpdev:	prepared rpdev to be used for creating endpoints
  *
-- 
2.17.1


  parent reply	other threads:[~2021-02-19 11:19 UTC|newest]

Thread overview: 41+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2021-02-19 11:14 [PATCH v5 00/16] introduce a generic IOCTL interface for RPMsg channels management Arnaud Pouliquen
2021-02-19 11:14 ` [PATCH v5 01/16] rpmsg: char: rename rpmsg_char_init to rpmsg_chrdev_init Arnaud Pouliquen
2021-02-19 11:14 ` [PATCH v5 02/16] rpmsg: move RPMSG_ADDR_ANY in user API Arnaud Pouliquen
2021-02-19 11:14 ` [PATCH v5 03/16] rpmsg: add short description of the IOCTL defined in UAPI Arnaud Pouliquen
2021-02-19 11:14 ` [PATCH v5 04/16] rpmsg: char: export eptdev create an destroy functions Arnaud Pouliquen
2021-03-02 17:57   ` Mathieu Poirier
2021-03-03 13:22     ` Arnaud POULIQUEN
2021-03-03 16:30       ` Mathieu Poirier
2021-02-19 11:14 ` [PATCH v5 05/16] rpmsg: char: dissociate the control device from the rpmsg class Arnaud Pouliquen
2021-03-02 18:01   ` Mathieu Poirier
2021-03-03 14:58     ` Arnaud POULIQUEN
2021-02-19 11:14 ` [PATCH v5 06/16] rpmsg: move the rpmsg control device from rpmsg_char to rpmsg_ctrl Arnaud Pouliquen
2021-03-02 18:35   ` Mathieu Poirier
2021-03-03 14:59     ` Arnaud POULIQUEN
2021-03-03 16:34       ` Mathieu Poirier
2021-02-19 11:14 ` Arnaud Pouliquen [this message]
2021-03-03 17:01   ` [PATCH v5 07/16] rpmsg: update rpmsg_chrdev_register_device function Mathieu Poirier
2021-02-19 11:14 ` [PATCH v5 08/16] rpmsg: glink: add sendto and trysendto ops Arnaud Pouliquen
2021-03-04 19:11   ` Mathieu Poirier
2021-03-05 10:46     ` Arnaud POULIQUEN
2021-03-05 16:55       ` Mathieu Poirier
2021-02-19 11:14 ` [PATCH v5 09/16] rpmsg: smd: " Arnaud Pouliquen
2021-02-19 11:14 ` [PATCH v5 10/16] rpmsg: char: use sendto to specify the message destination address Arnaud Pouliquen
2021-02-19 11:14 ` [PATCH v5 11/16] rpmsg: virtio: register the rpmsg_ctrl device Arnaud Pouliquen
2021-03-03 18:43   ` Mathieu Poirier
2021-03-04  9:20     ` Arnaud POULIQUEN
2021-02-19 11:14 ` [PATCH v5 12/16] rpmsg: ctrl: introduce RPMSG_CREATE_DEV_IOCTL Arnaud Pouliquen
2021-02-19 11:14 ` [PATCH v5 13/16] rpmsg: char: introduce __rpmsg_chrdev_create_eptdev function Arnaud Pouliquen
2021-03-04 18:55   ` Mathieu Poirier
2021-03-05 10:46     ` Arnaud POULIQUEN
2021-03-05 18:01       ` Mathieu Poirier
2021-03-04 19:05   ` Mathieu Poirier
2021-03-05 11:42     ` Arnaud POULIQUEN
2021-02-19 11:14 ` [PATCH v5 14/16] rpmsg: char: introduce a RPMsg driver for the RPMsg char device Arnaud Pouliquen
2021-02-19 11:15 ` [PATCH v5 15/16] rpmsg: char: no dynamic endpoint management for the default one Arnaud Pouliquen
2021-03-04 18:40   ` Mathieu Poirier
2021-03-05 11:09     ` Arnaud POULIQUEN
2021-03-05 17:39       ` Mathieu Poirier
2021-02-19 11:15 ` [PATCH v5 16/16] rpmsg: char: return an error if device already open Arnaud Pouliquen
2021-03-04 18:45   ` Mathieu Poirier
2021-03-17  9:29 ` [PATCH v5 00/16] introduce a generic IOCTL interface for RPMsg channels management Arnaud POULIQUEN

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20210219111501.14261-8-arnaud.pouliquen@foss.st.com \
    --to=arnaud.pouliquen@foss.st.com \
    --cc=agross@kernel.org \
    --cc=bjorn.andersson@linaro.org \
    --cc=linux-arm-msm@vger.kernel.org \
    --cc=linux-kernel@vger.kernel.org \
    --cc=linux-remoteproc@vger.kernel.org \
    --cc=linux-stm32@st-md-mailman.stormreply.com \
    --cc=mathieu.poirier@linaro.org \
    --cc=ohad@wizery.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.